get abstract method
Get the value of a field by name. To see what type it might be, check metadata.
Throws an ArgumentError if the field does not exist.
(see FieldMetadata.type)
Implementation
Object? get(String field);
Get the value of a field by name. To see what type it might be, check metadata.
Throws an ArgumentError if the field does not exist.
(see FieldMetadata.type)
Object? get(String field);