setFrom abstract method
Copies compatible fields from any other instance of CrystallisData.
Incompatible fields (missing or type-mismatched) are skipped.
Null values are skipped.
Implementation
void setFrom(CrystallisData other);
Copies compatible fields from any other instance of CrystallisData.
Incompatible fields (missing or type-mismatched) are skipped.
Null values are skipped.
void setFrom(CrystallisData other);