isNullable<T> function
Returns whether the given type T is a nullable of the given non-nullable type C.
Implementation
@pragma("vm:always-consider-inlining")
bool isNullable<T>() => null is T;
Returns whether the given type T is a nullable of the given non-nullable type C.
@pragma("vm:always-consider-inlining")
bool isNullable<T>() => null is T;